@@ -6,4 +6,6 @@ from sumatra.recordstore.django_store.models import Project
 class ProjectPermission(models.Model):
     user = models.ForeignKey(User)
     project = models.ForeignKey(Project)
-    
\ No newline at end of file
+
+    def __unicode__(self):
+        return u"Permission: %s can access %s" % (self.user, self.project)
